See [parent `readme.md`](../readme.md) for explanation of ids these docs use.

This dir lists delayed items (which are not worth their own `feature_story`),
but can still be referenced by their ids to link multiple parts of code to the single explanation.
